set YES_ 257
set NO_ 258
set ON_ 259
set OFF_ 260
set TRUE_ 261
set FALSE_ 262
set FONT_ 263
set FONTSIZE_ 264
set FONTSLANT_ 265
set FONTSTYLE_ 266
set FONTWEIGHT_ 267
set TIMES_ 268
set HELVETICA_ 269
set COURIER_ 270
set NORMAL_ 271
set BOLD_ 272
set ROMAN_ 273
set ITALIC_ 274
set INT_ 275
set REAL_ 276
set STRING_ 277
set A4_ 278
set ADD_ 279
set ARROW_ 280
set AUTO_ 281
set AXIS_ 282
set BACKGROUND_ 283
set BACKUP_ 284
set BAR_ 285
set BORDER_ 286
set BOTTOM_ 287
set CAP_ 288
set CATROM_ 289
set CIRCLE_ 290
set CLEAR_ 291
set CLOSE_ 292
set COLOR_ 293
set COLUMN_ 294
set COMMAND_ 295
set CROSS_ 296
set CUBIC_ 297
set CURRENT_ 298
set DASH_ 299
set DATA_ 300
set DATASET_ 301
set DELETE_ 302
set DESTINATION_ 303
set DIAMOND_ 304
set DUPLICATE_ 305
set EPS_ 306
set ERROR_ 307
set EXPORT_ 308
set FAMILY_ 309
set FILE_ 310
set FILENAME_ 311
set FILL_ 312
set FLIP_ 313
set FOREGROUND_ 314
set FORMAT_ 315
set GRAPH_ 316
set GRAY_ 317
set GRID_ 318
set GUI_ 319
set LABELS_ 320
set LANDSCAPE_ 321
set LAYOUT_ 322
set LEFT_ 323
set LEGAL_ 324
set LEGEND_ 325
set LETTER_ 326
set LINE_ 327
set LINEAR_ 328
set LIST_ 329
set LOAD_ 330
set LOG_ 331
set MAX_ 332
set MIN_ 333
set MODE_ 334
set NAME_ 335
set NEW_ 336
set NONE_ 337
set NUMBERS_ 338
set OPEN_ 339
set ORIENT_ 340
set ORIENTATION_ 341
set PAGESETUP_ 342
set PAGESIZE_ 343
set PALETTE_ 344
set PLOTAREA_ 345
set PLUS_ 346
set POINTER_ 347
set PORTRAIT_ 348
set POSITION_ 349
set POSTER_ 350
set PRINT_ 351
set PRINTER_ 352
set QUADRATIC_ 353
set RESTORE_ 354
set RGB_ 355
set RIGHT_ 356
set ROW_ 357
set SAVE_ 358
set SCALE_ 359
set SCATTER_ 360
set SCROSS_ 361
set SELECT_ 362
set SHAPE_ 363
set SHOW_ 364
set SIZE_ 365
set SLANT_ 366
set SMOOTH_ 367
set SPLUS_ 368
set SQUARE_ 369
set STATISTICS_ 370
set STDIN_ 371
set STEP_ 372
set STRIP_ 373
set STYLE_ 374
set SYMBOL_ 375
set TABLOID_ 376
set THEME_ 377
set TITLE_ 378
set TOP_ 379
set TRIANGLE_ 380
set WEIGHT_ 381
set WIDTH_ 382
set ZOOM_ 383
set XY_ 384
set XYEX_ 385
set XYEY_ 386
set XYEXEY_ 387
set XAXIS_ 388
set YAXIS_ 389
set GIF_ 390
set TIFF_ 391
set JPEG_ 392
set PNG_ 393
set PACKBITS_ 394
set DEFLATE_ 395
set DISCRETE_ 396
set ERRORBAR_ 397
set LINEARLINEAR_ 398
set LOGLINEAR_ 399
set LINEARLOG_ 400
set LOGLOG_ 401
set RANGE_ 402
set TYPE_ 403
set VIEW_ 404
