set YES_ 257
set NO_ 258
set ON_ 259
set OFF_ 260
set TRUE_ 261
set FALSE_ 262
set INT_ 263
set STRING_ 264
set BACKGROUND_ 265
set BGCOLOR_ 266
set COLOR_ 267
set NAN_ 268
set NANCOLOR_ 269
set CLEAR_ 270
set CLOSE_ 271
set IRAFALIGN_ 272
set OPEN_ 273
set PRECISION_ 274
set SAVE_ 275
set THEME_ 276
set THREADS_ 277
