set INT_ 257
set REAL_ 258
set STRING_ 259
set 3D_ 260
set AZ_ 261
set AZFROM_ 262
set AZTO_ 263
set BLINK_ 264
set EL_ 265
set ELFROM_ 266
set ELTO_ 267
set FADE_ 268
set FRAME_ 269
set FROM_ 270
set GIF_ 271
set MPEG_ 272
set NUMBER_ 273
set OSCILLATE_ 274
set REPEAT_ 275
set SLICE_ 276
set SLFROM_ 277
set SLTO_ 278
set TO_ 279
set ZOOM_ 280
set ZMFROM_ 281
set ZMTO_ 282
