set FONT_ 257
set FONTSIZE_ 258
set FONTSLANT_ 259
set FONTSTYLE_ 260
set FONTWEIGHT_ 261
set YES_ 262
set NO_ 263
set ON_ 264
set OFF_ 265
set TRUE_ 266
set FALSE_ 267
set IMAGE_ 268
set PHYSICAL_ 269
set AMPLIFIER_ 270
set DETECTOR_ 271
set WCS_ 272
set WCSA_ 273
set WCSB_ 274
set WCSC_ 275
set WCSD_ 276
set WCSE_ 277
set WCSF_ 278
set WCSG_ 279
set WCSH_ 280
set WCSI_ 281
set WCSJ_ 282
set WCSK_ 283
set WCSL_ 284
set WCSM_ 285
set WCSN_ 286
set WCSO_ 287
set WCSP_ 288
set WCSQ_ 289
set WCSR_ 290
set WCSS_ 291
set WCST_ 292
set WCSU_ 293
set WCSV_ 294
set WCSW_ 295
set WCSX_ 296
set WCSY_ 297
set WCSZ_ 298
set FK4_ 299
set B1950_ 300
set FK5_ 301
set J2000_ 302
set ICRS_ 303
set GALACTIC_ 304
set ECLIPTIC_ 305
set DEGREES_ 306
set SEXAGESIMAL_ 307
set INT_ 308
set STRING_ 309
set AUTO_ 310
set AUTOCENTROID_ 311
set BACKGROUND_ 312
set CENTROID_ 313
set COLOR_ 314
set DASH_ 315
set DELIM_ 316
set EPSILON_ 317
set EXCLUDE_ 318
set FILL_ 319
set FORMAT_ 320
set GROUP_ 321
set GROUPS_ 322
set INCLUDE_ 323
set ITERATION_ 324
set NL_ 325
set RADIUS_ 326
set SELECTED_ 327
set SHAPE_ 328
set SHOW_ 329
set SHOWTEXT_ 330
set SKY_ 331
set SKYFORMAT_ 332
set SOURCE_ 333
set STRIP_ 334
set SYSTEM_ 335
set WIDTH_ 336
set DS9_ 337
set XML_ 338
set CIAO_ 339
set SAOTNG_ 340
set PROS_ 341
set SAOIMAGE_ 342
set XY_ 343
set MFORMAT_ 344
set MSYSTEM_ 345
set MSKY_ 346
set MSKYFORMAT_ 347
set MSTRIP_ 348
set MDELIM_ 349
set MPROP_ 350
set MGROUP_ 351
