set RDB_ 257
set SB_ 258
set STARBASE_ 259
set CSV_ 260
set TSV_ 261
set YES_ 262
set NO_ 263
set ON_ 264
set OFF_ 265
set TRUE_ 266
set FALSE_ 267
set FONT_ 268
set FONTSIZE_ 269
set FONTSLANT_ 270
set FONTSTYLE_ 271
set FONTWEIGHT_ 272
set TIMES_ 273
set HELVETICA_ 274
set COURIER_ 275
set NORMAL_ 276
set BOLD_ 277
set ROMAN_ 278
set ITALIC_ 279
set WCS_ 280
set WCSA_ 281
set WCSB_ 282
set WCSC_ 283
set WCSD_ 284
set WCSE_ 285
set WCSF_ 286
set WCSG_ 287
set WCSH_ 288
set WCSI_ 289
set WCSJ_ 290
set WCSK_ 291
set WCSL_ 292
set WCSM_ 293
set WCSN_ 294
set WCSO_ 295
set WCSP_ 296
set WCSQ_ 297
set WCSR_ 298
set WCSS_ 299
set WCST_ 300
set WCSU_ 301
set WCSV_ 302
set WCSW_ 303
set WCSX_ 304
set WCSY_ 305
set WCSZ_ 306
set FK4_ 307
set B1950_ 308
set FK5_ 309
set J2000_ 310
set ICRS_ 311
set GALACTIC_ 312
set ECLIPTIC_ 313
set DEGREES_ 314
set ARCMIN_ 315
set ARCSEC_ 316
set SEXAGESIMAL_ 317
set INT_ 318
set REAL_ 319
set SEXSTR_ 320
set STRING_ 321
set 1AND2_ 322
set 1NOT2_ 323
set 1ONLY_ 324
set 2NOT1_ 325
set 2ONLY_ 326
set ADD_ 327
set ALLCOLS_ 328
set ALLROWS_ 329
set ANGLE_ 330
set ARROW_ 331
set BOX_ 332
set BOXCIRCLE_ 333
set BROADCAST_ 334
set CANCEL_ 335
set CDS_ 336
set CIRCLE_ 337
set CLEAR_ 338
set CLOSE_ 339
set COLOR_ 340
set CONDITION_ 341
set COORDINATE_ 342
set CROSS_ 343
set CROSSHAIR_ 344
set CURRENT_ 345
set DEC_ 346
set DECR_ 347
set DIAMOND_ 348
set EDIT_ 349
set ELLIPSE_ 350
set EXPORT_ 351
set ERROR_ 352
set FILE_ 353
set FILTER_ 354
set FITS_ 355
set FUNCTION_ 356
set HEADER_ 357
set HIDE_ 358
set IMPORT_ 359
set INCR_ 360
set LOAD_ 361
set LOCATION_ 362
set MATCH_ 363
set MAXROWS_ 364
set NAME_ 365
set NEW_ 366
set PANTO_ 367
set PLOT_ 368
set POINT_ 369
set PRINT_ 370
set PSKY_ 371
set PSYSTEM_ 372
set RA_ 373
set RADIUS_ 374
set REGIONS_ 375
set REMOVE_ 376
set RETRIEVE_ 377
set RETURN_ 378
set SAMP_ 379
set SAVE_ 380
set SEND_ 381
set SERVER_ 382
set SHAPE_ 383
set SHOW_ 384
set SIZE_ 385
set SIZE2_ 386
set SKY_ 387
set SKYFORMAT_ 388
set SORT_ 389
set SYMBOL_ 390
set SYSTEM_ 391
set TEXT_ 392
set UNIQUE_ 393
set UNITS_ 394
set UPDATE_ 395
set ADAC_ 396
set SAO_ 397
set INASAN_ 398
set IUCAA_ 399
set BEJING_ 400
set SAAO_ 401
