set FONT_ 257
set FONTSIZE_ 258
set FONTSLANT_ 259
set FONTSTYLE_ 260
set FONTWEIGHT_ 261
set TIMES_ 262
set HELVETICA_ 263
set COURIER_ 264
set NORMAL_ 265
set BOLD_ 266
set ROMAN_ 267
set ITALIC_ 268
set CUT_ 269
set COPY_ 270
set PASTE_ 271
set UNDO_ 272
set YES_ 273
set NO_ 274
set ON_ 275
set OFF_ 276
set TRUE_ 277
set FALSE_ 278
set IMAGE_ 279
set PHYSICAL_ 280
set AMPLIFIER_ 281
set DETECTOR_ 282
set WCS_ 283
set WCSA_ 284
set WCSB_ 285
set WCSC_ 286
set WCSD_ 287
set WCSE_ 288
set WCSF_ 289
set WCSG_ 290
set WCSH_ 291
set WCSI_ 292
set WCSJ_ 293
set WCSK_ 294
set WCSL_ 295
set WCSM_ 296
set WCSN_ 297
set WCSO_ 298
set WCSP_ 299
set WCSQ_ 300
set WCSR_ 301
set WCSS_ 302
set WCST_ 303
set WCSU_ 304
set WCSV_ 305
set WCSW_ 306
set WCSX_ 307
set WCSY_ 308
set WCSZ_ 309
set FK4_ 310
set B1950_ 311
set FK5_ 312
set J2000_ 313
set ICRS_ 314
set GALACTIC_ 315
set ECLIPTIC_ 316
set DEGREES_ 317
set SEXAGESIMAL_ 318
set INT_ 319
set REAL_ 320
set STRING_ 321
set ALL_ 322
set ANALYSIS_ 323
set AT_ 324
set AUTO_ 325
set AUTOCENTROID_ 326
set BACK_ 327
set BACKGROUND_ 328
set CENTROID_ 329
set CLOSE_ 330
set COLOR_ 331
set COMMAND_ 332
set COMPOSITE_ 333
set DASH_ 334
set DELETE_ 335
set DELETEALL_ 336
set DELIM_ 337
set DISSOLVE_ 338
set EDIT_ 339
set EPSILON_ 340
set EXCLUDE_ 341
set FILE_ 342
set FILL_ 343
set FIRST_ 344
set FIXED_ 345
set FORMAT_ 346
set FRONT_ 347
set GETINFO_ 348
set GROUP_ 349
set GROUPS_ 350
set INCLUDE_ 351
set INVERT_ 352
set ITERATION_ 353
set LAST_ 354
set LIST_ 355
set LOAD_ 356
set MOVE_ 357
set MOVEBACK_ 358
set MOVEFRONT_ 359
set NEW_ 360
set NL_ 361
set NONE_ 362
set OPEN_ 363
set PROPERTY_ 364
set RADIUS_ 365
set ROTATE_ 366
set SAVE_ 367
set SAVETEMPLATE_ 368
set SEGMENT_ 369
set SELECT_ 370
set SELECTALL_ 371
set SELECTNONE_ 372
set SHAPE_ 373
set SHOW_ 374
set SHOWTEXT_ 375
set SKY_ 376
set SKYFORMAT_ 377
set SOURCE_ 378
set STRIP_ 379
set SYSTEM_ 380
set TEMPLATE_ 381
set UPDATE_ 382
set WIDTH_ 383
set DS9_ 384
set XML_ 385
set CIAO_ 386
set SAOTNG_ 387
set PROS_ 388
set SAOIMAGE_ 389
set XY_ 390
set CIRCLE_ 391
set ELLIPSE_ 392
set BOX_ 393
set POLYGON_ 394
set POINT_ 395
set LINE_ 396
set VECTOR_ 397
set TEXT_ 398
set RULER_ 399
set COMPASS_ 400
set PROJECTION_ 401
set ANNULUS_ 402
set ELLIPSEANNULUS_ 403
set BOXANNULUS_ 404
set PANDA_ 405
set EPANDA_ 406
set BPANDA_ 407
set DIAMOND_ 408
set CROSS_ 409
set ARROW_ 410
set BOXCIRCLE_ 411
set HISTOGRAM_ 412
set PLOT2D_ 413
set PLOT3D_ 414
set RADIAL_ 415
set STATS_ 416
set MFORMAT_ 417
set MSYSTEM_ 418
set MSKY_ 419
