set RDB_ 257
set SB_ 258
set STARBASE_ 259
set CSV_ 260
set TSV_ 261
set YES_ 262
set NO_ 263
set ON_ 264
set OFF_ 265
set TRUE_ 266
set FALSE_ 267
set WCS_ 268
set WCSA_ 269
set WCSB_ 270
set WCSC_ 271
set WCSD_ 272
set WCSE_ 273
set WCSF_ 274
set WCSG_ 275
set WCSH_ 276
set WCSI_ 277
set WCSJ_ 278
set WCSK_ 279
set WCSL_ 280
set WCSM_ 281
set WCSN_ 282
set WCSO_ 283
set WCSP_ 284
set WCSQ_ 285
set WCSR_ 286
set WCSS_ 287
set WCST_ 288
set WCSU_ 289
set WCSV_ 290
set WCSW_ 291
set WCSX_ 292
set WCSY_ 293
set WCSZ_ 294
set FK4_ 295
set B1950_ 296
set FK5_ 297
set J2000_ 298
set ICRS_ 299
set GALACTIC_ 300
set ECLIPTIC_ 301
set DEGREES_ 302
set ARCMIN_ 303
set ARCSEC_ 304
set SEXAGESIMAL_ 305
set INT_ 306
set REAL_ 307
set SEXSTR_ 308
set STRING_ 309
set CANCEL_ 310
set CLEAR_ 311
set CLOSE_ 312
set COORDINATE_ 313
set CROSSHAIR_ 314
set CURRENT_ 315
set DECR_ 316
set EXPORT_ 317
set FILTER_ 318
set HIDE_ 319
set INCR_ 320
set LOAD_ 321
set NAME_ 322
set PANTO_ 323
set PRINT_ 324
set RADIUS_ 325
set REGIONS_ 326
set RETRIEVE_ 327
set SAVE_ 328
set SHOW_ 329
set SIZE_ 330
set SKY_ 331
set SKYFORMAT_ 332
set SORT_ 333
set SYSTEM_ 334
set UPDATE_ 335
set CXC_ 336
set HLA_ 337
