set RDB_ 257
set SB_ 258
set STARBASE_ 259
set CSV_ 260
set TSV_ 261
set INT_ 262
set REAL_ 263
set STRING_ 264
set CLEAR_ 265
set CLOSE_ 266
set CURRENT_ 267
set EXPORT_ 268
set EXT_ 269
set FIRST_ 270
set GOTO_ 271
set HISTOGRAM_ 272
set IMAGE_ 273
set IMPORT_ 274
set LAST_ 275
set LOAD_ 276
set MODE_ 277
set NEXT_ 278
set OPEN_ 279
set PLOT_ 280
set PREV_ 281
set NEWPLOT_ 282
set NEWGRAPH_ 283
set OVERPLOT_ 284
set XY_ 285
set XYEX_ 286
set XYEY_ 287
set XYEXEY_ 288
set VOT_ 289
set XML_ 290
