set CUT_ 257
set COPY_ 258
set PASTE_ 259
set UNDO_ 260
set YES_ 261
set NO_ 262
set ON_ 263
set OFF_ 264
set TRUE_ 265
set FALSE_ 266
set INT_ 267
set REAL_ 268
set STRING_ 269
set ALL_ 270
set BACK_ 271
set CLOSE_ 272
set COLOR_ 273
set COMMAND_ 274
set DASH_ 275
set DELETE_ 276
set FILL_ 277
set FRONT_ 278
set INVERT_ 279
set LIST_ 280
set LOAD_ 281
set MOVE_ 282
set NONE_ 283
set OPEN_ 284
set SAVE_ 285
set SELECT_ 286
set SHAPE_ 287
set SHOW_ 288
set WIDTH_ 289
set CIRCLE_ 290
set ELLIPSE_ 291
set BOX_ 292
set POLYGON_ 293
set LINE_ 294
set TEXT_ 295
set IMAGE_ 296
