set FONT_ 257
set FONTSIZE_ 258
set FONTSLANT_ 259
set FONTSTYLE_ 260
set FONTWEIGHT_ 261
set TIMES_ 262
set HELVETICA_ 263
set COURIER_ 264
set NORMAL_ 265
set BOLD_ 266
set ROMAN_ 267
set ITALIC_ 268
set YES_ 269
set NO_ 270
set ON_ 271
set OFF_ 272
set TRUE_ 273
set FALSE_ 274
set INT_ 275
set REAL_ 276
set STRING_ 277
set HASH_ 278
set VERSION_ 279
set GLOBAL_ 280
set ANGLE_ 281
set COLOR_ 282
set WIDTH_ 283
set FILL_ 284
set DASH_ 285
set JUSTIFY_ 286
set CIRCLE_ 287
set ELLIPSE_ 288
set BOX_ 289
set POLYGON_ 290
set LINE_ 291
set TEXT_ 292
set IMAGE_ 293
set LEFT_ 294
set CENTER_ 295
set RIGHT_ 296
