package provide DS9 1.0

######
# Begin autogenerated taccle (version 1.3) routines.
# Although taccle itself is protected by the GNU Public License (GPL)
# all user-supplied functions are protected by their respective
# author's license.  See http://mini.net/tcl/taccle for other details.
######

namespace eval plotsend {
    variable yylval {}
    variable table
    variable rules
    variable token {}
    variable yycnt 0
    variable yyerr 0
    variable save_state 0

    namespace export yylex
}

proc plotsend::YYABORT {} {
    return -code return 1
}

proc plotsend::YYACCEPT {} {
    return -code return 0
}

proc plotsend::YYERROR {} {
    variable yyerr
    set yyerr 1
}

proc plotsend::yyclearin {} {
    variable token
    variable yycnt
    set token {}
    incr yycnt -1
}

proc plotsend::yyerror {s} {
    puts stderr $s
}

proc plotsend::setupvalues {stack pointer numsyms} {
    upvar 1 1 y
    set y {}
    for {set i 1} {$i <= $numsyms} {incr i} {
        upvar 1 $i y
        set y [lindex $stack $pointer]
        incr pointer
    }
}

proc plotsend::unsetupvalues {numsyms} {
    for {set i 1} {$i <= $numsyms} {incr i} {
        upvar 1 $i y
        unset y
    }
}

array set plotsend::table {
  39:285,target 87
  38:275 reduce
  27:0 reduce
  1:305 shift
  21:303 shift
  33:261,target 67
  38:277 reduce
  31:273,target 70
  13:301,target 55
  21:295 shift
  48:0 reduce
  0:296,target 22
  38:279 reduce
  21:297 shift
  1:280,target 30
  70:0 reduce
  69:0 reduce
  30:302 reduce
  95:0,target 77
  41:287,target 96
  32:306,target 69
  6:0,target 7
  21:312 goto
  91:0 reduce
  87:0,target 65
  38:285 reduce
  6:278,target 48
  80:0,target 57
  38:286 reduce
  1:316 goto
  9:307 shift
  15:307,target 27
  72:0,target 35
  38:287 reduce
  31:302,target 70
  30:306 reduce
  1:317 goto
  64:0,target 5
  30:297 reduce
  56:0,target 80
  35:257 shift
  30:298 reduce
  24:0 reduce
  48:0,target 9
  35:258 shift
  35:260 shift
  35:259 shift
  33:258,target 67
  6:271 shift
  45:0 reduce
  39:262,target 87
  35:261 shift
  25:0,target 16
  0:304,target 25
  0:294,target 20
  9:315 goto
  17:0,target 8
  66:0 reduce
  33:298,target 67
  9:268,target 50
  10:0,target 33
  87:0 reduce
  41:285,target 94
  6:278 shift
  20:271,target 65
  42:268,target 97
  15:295,target 21
  21:0 reduce
  79:261,target 71
  35:273 shift
  32:273,target 69
  26:282 shift
  14:291,target 56
  15:274,target 10
  63:0 reduce
  33:306,target 67
  84:0 reduce
  32:302,target 69
  0:271,target 8
  14:319,target 57
  19:268,target 59
  17:0 reduce
  79:258,target 71
  41:262,target 90
  26:322,target 78
  38:0 reduce
  32:257 reduce
  26:308 shift
  36:286,target 86
  32:258 reduce
  26:309 shift
  99:0,target 12
  35:302 shift
  32:260 reduce
  32:259 reduce
  92:0,target 78
  79:298,target 71
  60:0 reduce
  59:0 reduce
  32:261 reduce
  0:300,target 24
  0:290,target 18
  3:0,target 14
  84:0,target 60
  76:0,target 26
  81:0 reduce
  68:0,target 41
  35:306 shift
  61:0,target 48
  55:292,target 99
  35:297 shift
  2:X shift
  53:0,target 34
  35:298 shift
  0:268,target 5
  2:Y shift
  45:0,target 46
  35:261,target 84
  37:0,target 88
  33:273,target 67
  26:320 goto
  14:0 reduce
  79:257 reduce
  29:0,target 2
  26:321 goto
  79:258 reduce
  41:262 shift
  26:322 goto
  22:0,target 27
  79:260 reduce
  79:259 reduce
  26:320,target 76
  14:0,target 79
  79:261 reduce
  32:273 reduce
  14:291 shift
  15:270,target 7
  56:0 reduce
  79:306,target 71
  77:0 reduce
  33:302,target 67
  30:260,target 68
  30:259,target 68
  0:257 shift
  4:313,target 46
  21:268,target 67
  98:0 reduce
  9:0 reduce
  35:258,target 81
  11:0 reduce
  41:275 shift
  26:X,target 36
  0:263 shift
  79:273 reduce
  0:264 shift
  10:268,target 53
  41:277 shift
  37:286,target 88
  0:265 shift
  19:314,target 64
  35:298,target 87
  2:Y,target 37
  41:279 shift
  1:289,target 32
  53:0 reduce
  0:268 shift
  0:269 shift
  0:270 shift
  32:302 reduce
  0:271 shift
  14:319 goto
  19:268 shift
  74:0 reduce
  0:272 shift
  41:285 shift
  30:257,target 68
  20:271 shift
  41:286 shift
  0:274 shift
  95:0 reduce
  41:287 shift
  32:306 reduce
  6:0 reduce
  79:273,target 71
  32:297 reduce
  0:264,target 3
  0:276 shift
  19:274 shift
  32:298 reduce
  30:297,target 68
  96:0,target 76
  28:0 accept
  0:279 shift
  2:x shift
  7:0,target 32
  88:0,target 66
  0:281 shift
  0:0,target 1
  2:y shift
  20:278 shift
  81:0,target 59
  37:262 reduce
  35:306,target 89
  0:282 shift
  79:302 reduce
  73:0,target 84
  50:0 reduce
  49:0 reduce
  0:283 shift
  65:0,target 19
  36:279,target 86
  0:284 shift
  57:0,target 25
  31:260,target 70
  31:259,target 70
  79:302,target 71
  71:0 reduce
  50:0,target 55
  49:0,target 54
  0:283,target 15
  79:306 reduce
  79:297 reduce
  34:0,target 17
  0:288 shift
  92:0 reduce
  79:298 reduce
  26:0,target 81
  0:290 shift
  0:300 shift
  2:321,target 41
  3:0 reduce
  18:0,target 28
  11:0,target 13
  38:286,target 85
  0:293 shift
  1:316,target 34
  9:307,target 51
  25:0 reduce
  0:304 shift
  0:294 shift
  37:275 reduce
  0:305 shift
  0:295 shift
  19:303 shift
  0:296 shift
  46:0 reduce
  37:277 reduce
  0:307 shift
  19:295 shift
  42:307,target 98
  26:x,target 38
  37:279 reduce
  36:277,target 86
  0:310 goto
  0:299 shift
  19:297 shift
  67:0 reduce
  31:257,target 70
  0:311 goto
  0:281,target 13
  2:y,target 39
  20:278,target 66
  35:273,target 85
  26:282,target 73
  88:0 reduce
  0:0 reduce
  37:285 reduce
  31:297,target 70
  2:318,target 40
  37:286 reduce
  19:314 goto
  37:287 reduce
  21:312,target 72
  22:0 reduce
  43:0 reduce
  37:279,target 88
  0:310,target 28
  0:299,target 23
  19:297,target 62
  35:302,target 88
  32:260,target 69
  32:259,target 69
  64:0 reduce
  36:275,target 86
  85:0 reduce
  12:268,target 54
  15:311,target 58
  93:0,target 72
  39:286,target 87
  31:305,target 79
  85:0,target 58
  77:0,target 82
  0:257,target 1
  18:0 reduce
  70:0,target 39
  69:0,target 37
  62:0,target 50
  54:0,target 15
  40:0 reduce
  39:0 reduce
  46:0,target 4
  37:277,target 88
  0:307,target 27
  19:295,target 61
  38:0,target 85
  32:257,target 69
  26:308,target 74
  61:0 reduce
  55:292 shift
  23:0,target 29
  82:0 reduce
  32:297,target 69
  0:276,target 11
  19:274,target 60
  38:279,target 85
  21:297,target 70
  36:0 reduce
  33:260,target 67
  33:259,target 67
  31:257 reduce
  37:275,target 88
  31:258 reduce
  0:305,target 26
  0:295,target 21
  19:303,target 63
  57:0 reduce
  31:260 reduce
  31:259 reduce
  31:261 reduce
  78:0 reduce
  41:286,target 95
  0:274,target 10
  99:0 reduce
  39:262 reduce
  38:277,target 85
  21:295,target 69
  33:257,target 67
  4:268,target 43
  31:273 reduce
  13:301 shift
  54:0 reduce
  0:293,target 19
  97:0,target 42
  33:297,target 67
  8:0,target 21
  9:267,target 49
  21:274,target 68
  90:0,target 75
  89:0,target 64
  75:0 reduce
  82:0,target 61
  74:0,target 89
  0:272,target 9
  96:0 reduce
  66:0,target 10
  7:0 reduce
  58:0,target 3
  51:0,target 56
  39:279,target 87
  10:268 shift
  43:0,target 45
  39:275 reduce
  79:260,target 71
  79:259,target 71
  29:0 reduce
  39:277 reduce
  38:275,target 85
  27:0,target 31
  1:305,target 33
  21:303,target 71
  36:287,target 86
  4:266,target 42
  19:0,target 47
  20:0,target 20
  51:0 reduce
  39:279 reduce
  72:0 reduce
  31:302 reduce
  39:285 reduce
  93:0 reduce
  39:286 reduce
  31:305 shift
  0:269,target 6
  0:270,target 7
  39:287 reduce
  31:306 reduce
  9:315,target 52
  31:297 reduce
  2:318 goto
  39:277,target 87
  31:298 reduce
  26:0 reduce
  2:321 goto
  79:257,target 71
  26:321,target 77
  47:0 reduce
  36:285,target 86
  36:262 reduce
  79:297,target 71
  0:288,target 17
  68:0 reduce
  30:261,target 68
  90:0 reduce
  89:0 reduce
  41:279,target 93
  35:260,target 83
  35:259,target 82
  6:271,target 47
  26:Y,target 37
  39:275,target 87
  23:0 reduce
  37:287,target 88
  36:275 reduce
  94:0,target 73
  44:0 reduce
  5:0,target 30
  86:0,target 63
  36:277 reduce
  15:268,target 5
  78:0,target 83
  71:0,target 38
  65:0 reduce
  36:279 reduce
  63:0,target 49
  30:258,target 68
  86:0 reduce
  47:0,target 18
  36:262,target 86
  15:268 shift
  40:0,target 24
  39:0,target 87
  15:270 shift
  41:277,target 92
  36:285 reduce
  0:265,target 4
  36:286 reduce
  35:257,target 80
  30:298,target 68
  24:0,target 22
  36:287 reduce
  4:266 shift
  16:0,target 23
  19:0 reduce
  20:0 reduce
  15:274 shift
  37:285,target 88
  33:257 reduce
  4:268 shift
  35:297,target 86
  33:258 reduce
  2:X,target 36
  33:260 reduce
  33:259 reduce
  33:261 reduce
  62:0 reduce
  31:261,target 70
  0:284,target 16
  4:274 shift
  83:0 reduce
  41:275,target 91
  0:263,target 2
  38:287,target 85
  30:306,target 68
  1:317,target 35
  16:0 reduce
  26:X shift
  26:Y shift
  37:0 reduce
  33:273 reduce
  26:y,target 39
  58:0 reduce
  42:268 shift
  31:258,target 70
  15:295 shift
  37:262,target 88
  0:282,target 14
  80:0 reduce
  15:307 shift
  4:307,target 45
  31:298,target 70
  15:299 shift
  12:268 shift
  15:311 goto
  98:0,target 43
  9:0,target 53
  13:0 reduce
  91:0,target 74
  38:285,target 85
  83:0,target 62
  4:307 shift
  75:0,target 90
  34:0 reduce
  67:0,target 40
  0:311,target 29
  60:0,target 52
  59:0,target 51
  32:261,target 69
  30:257 reduce
  52:0,target 6
  30:273,target 68
  30:258 reduce
  44:0,target 44
  33:302 reduce
  30:260 reduce
  30:259 reduce
  4:313 goto
  21:268 shift
  36:0,target 86
  30:261 reduce
  76:0 reduce
  28:0,target 0
  0:279,target 12
  2:x,target 38
  21:0,target 36
  33:306 reduce
  13:0,target 11
  97:0 reduce
  39:287,target 87
  33:297 reduce
  31:306,target 70
  8:0 reduce
  9:267 shift
  21:274 shift
  33:298 reduce
  9:268 shift
  10:0 reduce
  30:302,target 68
  1:280 shift
  4:274,target 44
  38:262 reduce
  1:282 shift
  52:0 reduce
  32:258,target 69
  30:273 reduce
  26:309,target 75
  42:307 shift
  38:262,target 85
  26:x shift
  1:282,target 31
  26:y shift
  73:0 reduce
  32:298,target 69
  1:289 shift
  94:0 reduce
  5:0 reduce
  15:299,target 23
}

array set plotsend::rules {
  9,l 310
  11,l 310
  32,l 311
  53,l 315
  74,l 318
  6,l 310
  28,l 310
  50,l 314
  49,l 314
  71,l 317
  3,l 310
  25,l 310
  46,l 313
  67,l 317
  0,l 323
  88,l 321
  22,l 310
  43,l 313
  64,l 316
  85,l 321
  18,l 310
  40,l 312
  39,l 312
  61,l 316
  82,l 320
  15,l 310
  36,l 312
  57,l 316
  78,l 318
  12,l 310
  33,l 311
  54,l 315
  75,l 318
  7,l 310
  29,l 311
  30,l 311
  51,l 314
  72,l 318
  4,l 310
  26,l 310
  47,l 314
  68,l 317
  90,l 322
  89,l 322
  1,l 310
  23,l 310
  44,l 313
  65,l 316
  86,l 321
  19,l 310
  20,l 310
  41,l 312
  62,l 316
  83,l 320
  16,l 310
  37,l 312
  58,l 316
  80,l 319
  79,l 319
  13,l 310
  34,l 311
  55,l 315
  76,l 318
  8,l 310
  10,l 310
  31,l 311
  52,l 314
  73,l 318
  5,l 310
  27,l 310
  48,l 314
  70,l 317
  69,l 317
  2,l 310
  24,l 310
  45,l 313
  66,l 316
  87,l 321
  21,l 310
  42,l 313
  63,l 316
  84,l 320
  17,l 310
  38,l 312
  60,l 316
  59,l 316
  81,l 320
  14,l 310
  35,l 311
  56,l 315
  77,l 318
}

array set plotsend::rules {
  63,dc 2
  12,dc 3
  77,dc 2
  26,dc 2
  3,dc 2
  41,dc 1
  55,dc 1
  70,dc 1
  69,dc 1
  18,dc 2
  84,dc 1
  33,dc 1
  9,dc 2
  47,dc 0
  62,dc 2
  11,dc 1
  76,dc 2
  25,dc 2
  2,dc 1
  40,dc 1
  39,dc 1
  54,dc 1
  68,dc 1
  17,dc 2
  83,dc 1
  32,dc 1
  8,dc 1
  46,dc 1
  61,dc 2
  10,dc 2
  75,dc 2
  24,dc 2
  90,dc 1
  89,dc 1
  1,dc 0
  38,dc 1
  53,dc 0
  67,dc 1
  16,dc 1
  82,dc 1
  31,dc 1
  7,dc 1
  45,dc 1
  60,dc 2
  59,dc 2
  74,dc 2
  23,dc 1
  0,dc 1
  88,dc 1
  37,dc 1
  52,dc 1
  66,dc 2
  15,dc 2
  81,dc 0
  29,dc 1
  30,dc 1
  6,dc 2
  44,dc 1
  58,dc 2
  73,dc 2
  22,dc 1
  87,dc 1
  36,dc 0
  51,dc 1
  65,dc 2
  14,dc 1
  80,dc 1
  79,dc 0
  28,dc 1
  5,dc 2
  43,dc 2
  57,dc 2
  72,dc 2
  21,dc 1
  86,dc 1
  35,dc 2
  50,dc 1
  49,dc 1
  64,dc 2
  13,dc 1
  78,dc 2
  27,dc 1
  4,dc 2
  42,dc 2
  56,dc 1
  71,dc 2
  19,dc 2
  20,dc 1
  85,dc 1
  34,dc 2
  48,dc 1
}

array set plotsend::rules {
  41,line 123
  7,line 75
  37,line 119
  4,line 70
  34,line 114
  90,line 195
  89,line 194
  1,line 67
  31,line 111
  86,line 189
  27,line 105
  83,line 184
  24,line 100
  80,line 178
  79,line 177
  21,line 97
  76,line 172
  17,line 90
  73,line 169
  14,line 85
  70,line 164
  69,line 163
  11,line 82
  66,line 158
  63,line 155
  60,line 151
  59,line 150
  56,line 144
  53,line 141
  50,line 136
  49,line 135
  46,line 130
  43,line 127
  9,line 80
  40,line 122
  39,line 121
  6,line 72
  36,line 118
  3,line 69
  33,line 113
  88,line 191
  29,line 109
  30,line 110
  85,line 188
  26,line 104
  82,line 183
  23,line 99
  78,line 174
  19,line 94
  20,line 96
  75,line 171
  16,line 87
  72,line 168
  13,line 84
  68,line 162
  10,line 81
  65,line 157
  62,line 154
  58,line 149
  55,line 143
  52,line 138
  48,line 134
  45,line 129
  42,line 126
  8,line 78
  38,line 120
  5,line 71
  35,line 115
  2,line 68
  32,line 112
  87,line 190
  28,line 106
  84,line 185
  25,line 101
  81,line 181
  22,line 98
  77,line 173
  18,line 92
  74,line 170
  15,line 86
  71,line 165
  12,line 83
  67,line 161
  64,line 156
  61,line 153
  57,line 148
  54,line 142
  51,line 137
  47,line 133
  44,line 128
}

array set plotsend::lr1_table {
  35 {{57 0 1} {58 0 1} {59 0 1} {60 0 1} {61 0 1} {62 0 1} {63 0 1} {64 0 1} {65 0 1} {66 0 1}}
  66,trans {}
  36 {{86 {262 275 277 279 285 286 287} 1}}
  85,trans {}
  37 {{88 {262 275 277 279 285 286 287} 1}}
  38 {{85 {262 275 277 279 285 286 287} 1}}
  40 {{24 0 2}}
  39 {{87 {262 275 277 279 285 286 287} 1}}
  41 {{72 0 1} {73 0 1} {74 0 1} {75 0 1} {76 0 1} {77 0 1} {78 0 1}}
  42 {{42 0 1} {43 0 1}}
  43 {{45 0 1}}
  44 {{44 0 1}}
  45 {{46 0 1}}
  46 {{4 0 2}}
  47 {{18 0 2}}
  48 {{9 0 2}}
  49 {{54 0 1}}
  50 {{55 0 1}}
  27,trans {}
  51 {{56 0 1}}
  46,trans {}
  52 {{6 0 2}}
  65,trans {}
  53 {{34 0 2}}
  84,trans {}
  54 {{15 0 2}}
  55 {{12 0 2}}
  56 {{80 0 1}}
  57 {{25 0 2}}
  58 {{3 0 2}}
  59 {{51 0 1}}
  60 {{52 0 1}}
  61 {{48 0 1}}
  62 {{50 0 1}}
  63 {{49 0 1}}
  64 {{5 0 2}}
  65 {{19 0 2}}
  66 {{10 0 2}}
  26,trans {{X 73} {Y 74} {x 75} {y 76} {282 77} {308 78} {309 79} {320 80} {321 81} {322 82}}
  67 {{40 0 1}}
  45,trans {}
  68 {{41 0 1}}
  64,trans {}
  69 {{37 0 1}}
  70 {{39 0 1}}
  83,trans {}
  71 {{38 0 1}}
  72 {{35 0 2}}
  73 {{86 0 1}}
  74 {{88 0 1}}
  75 {{85 0 1}}
  76 {{87 0 1}}
  77 {{84 0 1}}
  78 {{89 0 1}}
  79 {{90 0 1}}
  80 {{26 0 2}}
  81 {{82 0 1}}
  82 {{83 0 1}}
  25,trans {}
  83 {{71 {257 258 259 260 261 273 297 298 302 306} 2}}
  84 {{57 0 2}}
  44,trans {}
  85 {{59 0 2}}
  63,trans {}
  86 {{61 0 2}}
  82,trans {}
  87 {{62 0 2}}
  0 {{0 0 0} {1 0 0} {2 0 0} {3 0 0} {4 0 0} {5 0 0} {6 0 0} {7 0 0} {8 0 0} {9 0 0} {10 0 0} {11 0 0} {12 0 0} {13 0 0} {14 0 0} {15 0 0} {16 0 0} {17 0 0} {18 0 0} {19 0 0} {20 0 0} {21 0 0} {22 0 0} {23 0 0} {24 0 0} {25 0 0} {26 0 0} {27 0 0} {28 0 0} {29 0 0} {30 0 0} {31 0 0} {32 0 0} {33 0 0} {34 0 0} {35 0 0}}
  88 {{60 0 2}}
  1 {{17 0 1} {57 0 0} {58 0 0} {59 0 0} {60 0 0} {61 0 0} {62 0 0} {63 0 0} {64 0 0} {65 0 0} {66 0 0} {67 {257 258 259 260 261 273 297 298 302 306} 0} {68 {257 258 259 260 261 273 297 298 302 306} 0} {69 {257 258 259 260 261 273 297 298 302 306} 0} {70 {257 258 259 260 261 273 297 298 302 306} 0} {71 {257 258 259 260 261 273 297 298 302 306} 0}}
  89 {{58 0 2}}
  90 {{63 0 2}}
  2 {{24 0 1} {72 0 0} {73 0 0} {74 0 0} {75 0 0} {76 0 0} {77 0 0} {78 0 0} {85 {262 275 277 279 285 286 287} 0} {86 {262 275 277 279 285 286 287} 0} {87 {262 275 277 279 285 286 287} 0} {88 {262 275 277 279 285 286 287} 0}}
  91 {{65 0 2}}
  3 {{14 0 1}}
  92 {{66 0 2}}
  4 {{4 0 1} {42 0 0} {43 0 0} {44 0 0} {45 0 0} {46 0 0}}
  93 {{64 0 2}}
  5 {{30 0 1}}
  94 {{75 0 2}}
  6 {{7 0 1} {9 0 1} {18 0 1}}
  95 {{74 0 2}}
  7 {{32 0 1}}
  96 {{78 0 2}}
  8 {{21 0 1}}
  97 {{72 0 2}}
  9 {{6 0 1} {53 0 0} {54 0 0} {55 0 0} {56 0 0}}
  98 {{73 0 2}}
  24,trans {}
  99 {{77 0 2}}
  43,trans {}
  62,trans {}
  81,trans {}
  99,trans {}
  23,trans {}
  42,trans {{268 101} {307 102}}
  61,trans {}
  79,trans {}
  80,trans {}
  98,trans {}
  9,trans {{267 49} {268 50} {307 51} {315 52}}
  22,trans {}
  41,trans {{262 94} {275 95} {277 96} {279 97} {285 98} {286 99} {287 100}}
  59,trans {}
  60,trans {}
  78,trans {}
  97,trans {}
  8,trans {}
  100 {{76 0 2}}
  101 {{42 0 2}}
  102 {{43 0 2}}
  103 {{12 0 3}}
  21,trans {{268 67} {274 68} {295 69} {297 70} {303 71} {312 72}}
  39,trans {}
  40,trans {}
  58,trans {}
  77,trans {}
  96,trans {}
  7,trans {}
  19,trans {{268 59} {274 60} {295 61} {297 62} {303 63} {314 64}}
  20,trans {{271 65} {278 66}}
  38,trans {}
  57,trans {}
  76,trans {}
  95,trans {}
  6,trans {{271 47} {278 48}}
  18,trans {}
  37,trans {}
  56,trans {}
  75,trans {}
  94,trans {}
  5,trans {}
  17,trans {}
  36,trans {}
  55,trans {{292 103}}
  74,trans {}
  93,trans {}
  4,trans {{266 42} {268 43} {274 44} {307 45} {313 46}}
  16,trans {}
  35,trans {{257 84} {258 85} {259 86} {260 87} {261 88} {273 89} {297 90} {298 91} {302 92} {306 93}}
  54,trans {}
  73,trans {}
  92,trans {}
  3,trans {}
  15,trans {{268 5} {270 7} {274 10} {295 21} {299 23} {307 27} {311 58}}
  34,trans {}
  53,trans {}
  72,trans {}
  91,trans {}
  2,trans {{X 36} {Y 37} {x 38} {y 39} {318 40} {321 41}}
  14,trans {{291 56} {319 57}}
  33,trans {}
  52,trans {}
  71,trans {}
  90,trans {}
  89,trans {}
  1,trans {{280 30} {282 31} {289 32} {305 33} {316 34} {317 35}}
  103,trans {}
  13,trans {{301 55}}
  32,trans {}
  51,trans {}
  69,trans {}
  70,trans {}
  88,trans {}
  0,trans {{257 1} {263 2} {264 3} {265 4} {268 5} {269 6} {270 7} {271 8} {272 9} {274 10} {276 11} {279 12} {281 13} {282 14} {283 15} {284 16} {288 17} {290 18} {293 19} {294 20} {295 21} {296 22} {299 23} {300 24} {304 25} {305 26} {307 27} {310 28} {311 29}}
  102,trans {}
  12,trans {{268 54}}
  31,trans {{305 83}}
  49,trans {}
  50,trans {}
  68,trans {}
  87,trans {}
  101,trans {}
  10 {{33 0 1} {34 0 1}}
  11 {{13 0 1}}
  12 {{15 0 1}}
  13 {{11 0 1} {12 0 1}}
  14 {{25 0 1} {79 0 0} {80 0 0}}
  15 {{3 0 1} {29 0 0} {30 0 0} {31 0 0} {32 0 0} {33 0 0} {34 0 0} {35 0 0}}
  11,trans {}
  16 {{23 0 1}}
  29,trans {}
  30,trans {}
  17 {{8 0 1}}
  48,trans {}
  18 {{28 0 1}}
  67,trans {}
  20 {{10 0 1} {19 0 1} {20 0 1}}
  19 {{5 0 1} {47 0 0} {48 0 0} {49 0 0} {50 0 0} {51 0 0} {52 0 0}}
  86,trans {}
  21 {{35 0 1} {36 0 0} {37 0 0} {38 0 0} {39 0 0} {40 0 0} {41 0 0}}
  22 {{27 0 1}}
  100,trans {}
  23 {{29 0 1}}
  24 {{22 0 1}}
  25 {{16 0 1}}
  26 {{26 0 1} {81 0 0} {82 0 0} {83 0 0} {84 0 0} {85 0 0} {86 0 0} {87 0 0} {88 0 0} {89 0 0} {90 0 0}}
  27 {{31 0 1}}
  28 {{0 0 1}}
  30 {{68 {257 258 259 260 261 273 297 298 302 306} 1}}
  29 {{2 0 1}}
  31 {{70 {257 258 259 260 261 273 297 298 302 306} 1} {71 {257 258 259 260 261 273 297 298 302 306} 1}}
  32 {{69 {257 258 259 260 261 273 297 298 302 306} 1}}
  10,trans {{268 53}}
  33 {{67 {257 258 259 260 261 273 297 298 302 306} 1}}
  28,trans {}
  34 {{17 0 2}}
  47,trans {}
}

array set plotsend::token_id_table {
  286 MAX_
  286,t 0
  287 MIN_
  292,line 45
  302,line 55
  288 MODE_
  317,t 1
  265,title BAR
  289 NUMBERS_
  290 NAME_
  300 STATISTICS_
  284,title LIST
  291 POSITION_
  301 STRIP_
  313,title {}
  292 SCALE_
  302 STYLE_
  288,line 41
  293 SCATTER_
  303 SYMBOL_
  294 SELECT_
  304 THEME_
  305 TITLE_
  295 SHAPE_
  306 WEIGHT_
  296 SHOW_
  307 WIDTH_
  262,t 0
  297 SIZE_
  308 XAXIS_
  285,line 38
  298 SLANT_
  310 plotsend
  309 YAXIS_
  299 SMOOTH_
  311 line
  283,t 0
  312 lineshape
  313 bar
  314,t 1
  314 scatter
  282,line 35
  315 errorr
  316 fontt
  264,title BACKGROUND
  317 fontType
  283,title LINE
  318 axis
  312,title {}
  320 title
  319 legend
  278,line 31
  321 xy
  error,line 65
  322 xyaxis
  258,t 0
  323 start'
  275,line 28
  279,t 0
  280,t 0
  311,t 1
  272,line 25
  263,title AXIS
  282,title LEGEND
  311,title {}
  268,line 21
  276,t 0
  Y,t 0
  265,line 18
  307,t 0
  297,t 0
  262,line 15
  0,t 0
  0 {$}
  262,title AUTO
  281,title LAYOUT
  310,title {}
  error,t 0
  309,title YAXIS
  299,title SMOOTH
  258,line 8
  273,t 0
  294,t 0
  304,t 0
  321,line 187
  317,line 160
  261,title FONTWEIGHT
  279,title GRID
  280,title LABELS
  308,title XAXIS
  269,t 0
  270,t 0
  298,title SLANT
  314,line 132
  291,t 0
  301,t 0
  322,t 1
  y,t 0
  311,line 108
  307,line 60
  266,t 0
  260,title FONTSTYLE
  259,title FONTSLANT
  297,line 50
  278,title GRAPH
  307,title WIDTH
  297,title SIZE
  287,t 0
  294,line 47
  304,line 57
  318,t 1
  X X
  error,title {}
  291,line 44
  301,line 54
  Y Y
  263,t 0
  258,title FONTSIZE
  287,line 40
  277,title FORMAT
  284,t 0
  306,title WEIGHT
  296,title SHOW
  315,t 1
  284,line 37
  281,line 34
  260,t 0
  259,t 0
  281,t 0
  257,title FONT
  277,line 30
  276,title FOREGROUND
  312,t 1
  305,title TITLE
  295,title SHAPE
  274,line 27
  Y,line 190
  271,line 24
  x x
  277,t 0
  y y
  308,t 0
  267,line 20
  298,t 0
  275,title FLIP
  294,title SELECT
  304,title THEME
  323,title {}
  264,line 17
  261,line 11
  274,t 0
  305,t 0
  295,t 0
  257,line 7
  274,title FILL
  323,line 196
  293,title SCATTER
  303,title SYMBOL
  322,title {}
  320,line 180
  319,line 176
  error error
  271,t 0
  y,line 189
  292,t 0
  302,t 0
  316,line 146
  323,t 1
  273,title FAMILY
  313,line 125
  292,title SCALE
  302,title STYLE
  321,title {}
  267,t 0
  310,line 66
  309,line 62
  299,line 52
  288,t 0
  320,t 1
  319,t 1
  306,line 59
  296,line 49
  272,title ERROR
  291,title POSITION
  293,line 46
  301,title STRIP
  303,line 56
  320,title {}
  319,title {}
  264,t 0
  Y,title {}
  285,t 0
  289,line 42
  290,line 43
  300,line 53
  316,t 1
  286,line 39
  271,title DATASET
  261,t 0
  283,line 36
  289,title NUMBERS
  290,title NAME
  300,title STATISTICS
  318,title {}
  282,t 0
  X,title {}
  279,line 32
  280,line 33
  313,t 1
  276,line 29
  257,t 0
  269,title CURRENT
  270,title DASH
  273,line 26
  288,title MODE
  317,title {}
  278,t 0
  X,line 188
  310,t 1
  309,t 0
  299,t 0
  269,line 22
  270,line 23
  y,title {}
  266,line 19
  268,title COLOR
  275,t 0
  263,line 16
  287,title MIN
  X,t 0
  316,title {}
  306,t 0
  296,t 0
  260,line 10
  259,line 9
  x,title {}
  322,line 193
  272,t 0
  267,title CAP
  257 FONT_
  286,title MAX
  293,t 0
  303,t 0
  315,title {}
  258 FONTSIZE_
  318,line 167
  260 FONTSTYLE_
  259 FONTSLANT_
  261 FONTWEIGHT_
  262 AUTO_
  263 AXIS_
  x,line 187
  264 BACKGROUND_
  315,line 140
  265 BAR_
  266 BORDER_
  267 CAP_
  268,t 0
  268 COLOR_
  269 CURRENT_
  270 DASH_
  312,line 117
  271 DATASET_
  272 ERROR_
  289,t 0
  290,t 0
  300,t 0
  266,title BORDER
  273 FAMILY_
  274 FILL_
  285,title LOG
  321,t 1
  314,title {}
  275 FLIP_
  308,line 61
  276 FOREGROUND_
  298,line 51
  x,t 0
  277 FORMAT_
  278 GRAPH_
  279 GRID_
  280 LABELS_
  281 LAYOUT_
  305,line 58
  282 LEGEND_
  295,line 48
  265,t 0
  283 LINE_
  284 LIST_
  285 LOG_
}

proc plotsend::yyparse {} {
    variable yylval
    variable table
    variable rules
    variable token
    variable yycnt
    variable lr1_table
    variable token_id_table
    variable yyerr
    variable save_state

    set yycnt 0
    set state_stack {0}
    set value_stack {{}}
    set token ""
    set accepted 0
    set yyerr 0
    set save_state 0

    while {$accepted == 0} {
        set state [lindex $state_stack end]
        if {$token == ""} {
            set yylval ""
            set token [yylex]
            set buflval $yylval
	    if {$token>0} {
	        incr yycnt
            }
        }
        if {![info exists table($state:$token)] || $yyerr} {
	    if {!$yyerr} {
	        set save_state $state
	    }
            # pop off states until error token accepted
            while {[llength $state_stack] > 0 && \
                       ![info exists table($state:error)]} {
                set state_stack [lrange $state_stack 0 end-1]
                set value_stack [lrange $value_stack 0 \
                                       [expr {[llength $state_stack] - 1}]]
                set state [lindex $state_stack end]
            }
            if {[llength $state_stack] == 0} {
 
	        set rr { }
                if {[info exists lr1_table($save_state,trans)] && [llength $lr1_table($save_state,trans)] >= 1} {
                    foreach trans $lr1_table($save_state,trans) {
                        foreach {tok_id nextstate} $trans {
			    set ss $token_id_table($tok_id,title)
			    if {$ss != {}} {
			        append rr "$ss, "
                            }
                        }
                    }
                }
		set rr [string trimleft $rr { }]
		set rr [string trimright $rr {, }]
                yyerror "parse error, expecting: $rr"


                return 1
            }
            lappend state_stack [set state $table($state:error,target)]
            lappend value_stack {}
            # consume tokens until it finds an acceptable one
            while {![info exists table($state:$token)]} {
                if {$token == 0} {
                    yyerror "end of file while recovering from error"
                    return 1
                }
                set yylval {}
                set token [yylex]
                set buflval $yylval
            }
            continue
        }
        switch -- $table($state:$token) {
            shift {
                lappend state_stack $table($state:$token,target)
                lappend value_stack $buflval
                set token ""
            }
            reduce {
                set rule $table($state:$token,target)
                set ll $rules($rule,l)
                if {[info exists rules($rule,e)]} {
                    set dc $rules($rule,e)
                } else {
                    set dc $rules($rule,dc)
                }
                set stackpointer [expr {[llength $state_stack]-$dc}]
                setupvalues $value_stack $stackpointer $dc
                set _ $1
                set yylval [lindex $value_stack end]
                switch -- $rule {
                    1 { ProcessSendCmdGet iap plots }
                    7 { PlotSendCmdRef }
                    8 { ProcessSendCmdCVARGet mode }
                    9 { ProcessSendCmdCVARGet graph,current }
                    10 { ProcessSendCmdCVARGet graph,current }
                    11 { ProcessSendCmdCVARGet canvas,layout }
                    12 { ProcessSendCmdCVARGet canvas,layout,strip,scale }
                    13 { ProcessSendCmdCVARGet canvas,foreground }
                    14 { ProcessSendCmdCVARGet canvas,background }
                    15 { ProcessSendCmdCVARGet canvas,grid,color }
                    16 { ProcessSendCmdCVARGetYesNo canvas,theme }
                    18 { ProcessSendCmdCVARGet graph,ds,current }
                    19 { ProcessSendCmdCVARGet graph,ds,current }
                    20 { ProcessSendCmdCVARGet graph,ds,current }
                    21 { ProcessSendCmdCVARGet graph,ds,current }
                    22 { ProcessSendCmdCVAR PlotStatsGenerate }
                    23 { ProcessSendCmdCVAR PlotListGenerate }
                    27 { ProcessSendCmdCVARGetYesNo graph,ds,show }
                    28 { ProcessSendCmdCVARGet graph,ds,name }
                    29 { ProcessSendCmdCVARGet graph,ds,line,smooth }
                    30 { ProcessSendCmdCVARGet graph,ds,line,color }
                    31 { ProcessSendCmdCVARGet graph,ds,line,width }
                    32 { ProcessSendCmdCVARGetYesNo graph,ds,line,dash }
                    33 { ProcessSendCmdCVARGetYesNo graph,ds,line,fill }
                    34 { ProcessSendCmdCVARGet graph,ds,line,fill,color }
                    36 { ProcessSendCmdCVARGet graph,ds,line,shape,symbol }
                    37 { ProcessSendCmdCVARGet graph,ds,line,shape,symbol }
                    38 { ProcessSendCmdCVARGet graph,ds,line,shape,symbol }
                    39 { ProcessSendCmdCVARGet graph,ds,line,shape,size }
                    40 { ProcessSendCmdCVARGet graph,ds,line,shape,color }
                    41 { ProcessSendCmdCVARGetYesNo graph,ds,line,shape,fill }
                    42 { ProcessSendCmdCVARGet graph,ds,bar,border,color }
                    43 { ProcessSendCmdCVARGet graph,ds,bar,border,width }
                    44 { ProcessSendCmdCVARGetYesNo graph,ds,bar,fill }
                    45 { ProcessSendCmdCVARGet graph,ds,bar,color }
                    46 { ProcessSendCmdCVARGet graph,ds,bar,width }
                    47 { ProcessSendCmdCVARGet graph,ds,scatter,shape,symbol }
                    48 { ProcessSendCmdCVARGet graph,ds,scatter,shape,symbol }
                    49 { ProcessSendCmdCVARGet graph,ds,scatter,shape,symbol }
                    50 { ProcessSendCmdCVARGet graph,ds,scatter,shape,size }
                    51 { ProcessSendCmdCVARGet graph,ds,scatter,shape,color }
                    52 { ProcessSendCmdCVARGetYesNo graph,ds,scatter,shape,fill }
                    53 { ProcessSendCmdCVARGetYesNo graph,ds,error }
                    54 { ProcessSendCmdCVARGetYesNo graph,ds,error,cap }
                    55 { ProcessSendCmdCVARGet graph,ds,error,color }
                    56 { ProcessSendCmdCVARGet graph,ds,error,width }
                    57 { ProcessSendCmdCVARGet "$1,family" }
                    58 { ProcessSendCmdCVARGet "$1,family" }
                    59 { ProcessSendCmdCVARGet "$1,size" }
                    60 { ProcessSendCmdCVARGet "$1,weight" }
                    61 { ProcessSendCmdCVARGet "$1,slant" }
                    62 { ProcessSendCmdCVARGet "$1,weight" }
                    63 { ProcessSendCmdCVARGet "$1,size" }
                    64 { ProcessSendCmdCVARGet "$1,weight" }
                    65 { ProcessSendCmdCVARGet "$1,slant" }
                    66 { ProcessSendCmdCVARGet "$1,weight" }
                    67 { set _ canvas,title }
                    68 { set _ canvas,axis,title }
                    69 { set _ canvas,axis,font }
                    70 { set _ canvas,legend,font }
                    71 { set _ canvas,legend,title }
                    72 { ProcessSendCmdCVARGetYesNo "graph,axis,$1,grid" }
                    73 { ProcessSendCmdCVARGetYesNo "graph,axis,$1,log" }
                    74 { ProcessSendCmdCVARGetYesNo "graph,axis,$1,flip" }
                    75 { ProcessSendCmdCVARGetYesNo "graph,axis,$1,auto" }
                    76 { ProcessSendCmdCVARGet "graph,axis,$1,min" }
                    77 { ProcessSendCmdCVARGet "graph,axis,$1,max" }
                    78 { ProcessSendCmdCVARGet "graph,axis,$1,format" }
                    79 { ProcessSendCmdCVARGetYesNo graph,legend }
                    80 { ProcessSendCmdCVARGet graph,legend,position }
                    81 { ProcessSendCmdCVARGet graph,title }
                    82 { ProcessSendCmdCVARGet "graph,axis,$1,title" }
                    83 { ProcessSendCmdCVARGet "graph,axis,$1,title" }
                    84 { ProcessSendCmdCVARGet graph,legend,title }
                    85 { set _ x }
                    86 { set _ x }
                    87 { set _ y }
                    88 { set _ y }
                    89 { set _ x }
                    90 { set _ y }
                }
                unsetupvalues $dc
                # pop off tokens from the stack if normal rule
                if {![info exists rules($rule,e)]} {
                    incr stackpointer -1
                    set state_stack [lrange $state_stack 0 $stackpointer]
                    set value_stack [lrange $value_stack 0 $stackpointer]
                }
                # now do the goto transition
                lappend state_stack $table([lindex $state_stack end]:$ll,target)
                lappend value_stack $_
            }
            accept {
                set accepted 1
            }
            goto -
            default {
                puts stderr "Internal parser error: illegal command $table($state:$token)"
                return 2
            }
        }
    }
    return 0
}

######
# end autogenerated taccle functions
######

proc plotsend::yyerror {msg} {
     variable yycnt
     variable yy_current_buffer
     variable index_

     ParserError $msg $yycnt $yy_current_buffer $index_
}
