set YES_ 257
set NO_ 258
set ON_ 259
set OFF_ 260
set TRUE_ 261
set FALSE_ 262
set IMAGE_ 263
set PHYSICAL_ 264
set AMPLIFIER_ 265
set DETECTOR_ 266
set WCS_ 267
set WCSA_ 268
set WCSB_ 269
set WCSC_ 270
set WCSD_ 271
set WCSE_ 272
set WCSF_ 273
set WCSG_ 274
set WCSH_ 275
set WCSI_ 276
set WCSJ_ 277
set WCSK_ 278
set WCSL_ 279
set WCSM_ 280
set WCSN_ 281
set WCSO_ 282
set WCSP_ 283
set WCSQ_ 284
set WCSR_ 285
set WCSS_ 286
set WCST_ 287
set WCSU_ 288
set WCSV_ 289
set WCSW_ 290
set WCSX_ 291
set WCSY_ 292
set WCSZ_ 293
set STRING_ 294
set ADVANCED_ 295
set BASIC_ 296
set BUTTONS_ 297
set COLORBAR_ 298
set COLORBARNUMERICS_ 299
set FILENAME_ 300
set FRAME_ 301
set GRAPH_ 302
set HORIZONTAL_ 303
set HORZGRAPH_ 304
set ICONS_ 305
set INFO_ 306
set KEYVALUE_ 307
set KEYWORD_ 308
set LAYOUT_ 309
set LOWHIGH_ 310
set MAGNIFIER_ 311
set MINMAX_ 312
set MULTI_ 313
set OBJECT_ 314
set PANNER_ 315
set UNITS_ 316
set VERTICAL_ 317
set VERTGRAPH_ 318
set RED_ 319
set BLUE_ 320
set GREEN_ 321
