set RDB_ 257
set SB_ 258
set STARBASE_ 259
set CSV_ 260
set TSV_ 261
set WCS_ 262
set WCSA_ 263
set WCSB_ 264
set WCSC_ 265
set WCSD_ 266
set WCSE_ 267
set WCSF_ 268
set WCSG_ 269
set WCSH_ 270
set WCSI_ 271
set WCSJ_ 272
set WCSK_ 273
set WCSL_ 274
set WCSM_ 275
set WCSN_ 276
set WCSO_ 277
set WCSP_ 278
set WCSQ_ 279
set WCSR_ 280
set WCSS_ 281
set WCST_ 282
set WCSU_ 283
set WCSV_ 284
set WCSW_ 285
set WCSX_ 286
set WCSY_ 287
set WCSZ_ 288
set FK4_ 289
set B1950_ 290
set FK5_ 291
set J2000_ 292
set ICRS_ 293
set GALACTIC_ 294
set ECLIPTIC_ 295
set DEGREES_ 296
set ARCMIN_ 297
set ARCSEC_ 298
set SEXAGESIMAL_ 299
set INT_ 300
set REAL_ 301
set SEXSTR_ 302
set STRING_ 303
set CANCEL_ 304
set CLEAR_ 305
set CLOSE_ 306
set COORDINATE_ 307
set CROSSHAIR_ 308
set CURRENT_ 309
set EXPORT_ 310
set NAME_ 311
set PRINT_ 312
set RADIUS_ 313
set RETRIEVE_ 314
set SAVE_ 315
set SIZE_ 316
set SKY_ 317
set SKYFORMAT_ 318
set SYSTEM_ 319
set UPDATE_ 320
set 2MASS_ 321
set AKARI_ 322
set ASTROWISE_ 323
set CADC_ 324
set CXC_ 325
set HLA_ 326
set MAST_ 327
set SDSS_ 328
set SKYVIEW_ 329
set TGSSADR_ 330
